@@ -31,6 +31,7 @@ from . import (
     __version__, stats as _stats,
     utils as _utils, plots as _plots
 )
+from dateutil.relativedelta import relativedelta
 
 try:
     from IPython.core.display import (
@@ -72,6 +73,7 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
     # prepare timeseries
     returns = _utils._prepare_returns(returns)
     if benchmark is not None:
+        tpl = tpl.replace('{{benchmark_title}}', f"Benchmark is {benchmark} | ")
         benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
         if match_dates is True:
             returns, benchmark = _match_dates(returns, benchmark)
@@ -264,9 +266,9 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
 
     dd = _stats.to_drawdown_series(returns)
     col = _stats.drawdown_details(dd).columns[4]
-    dd_info = _stats.drawdown_details(dd).sort_values(by = col, 
+    dd_info = _stats.drawdown_details(dd).sort_values(by = col,
                                                        ascending = True)[:5]
-     
+
     if not dd_info.empty:
         dd_info.index = range(1, min(6, len(dd_info)+1))
         dd_info.columns = map(lambda x: str(x).title(), dd_info.columns)
@@ -350,10 +352,13 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
     win_year, _ = _get_trading_periods(periods_per_year)
 
-    if benchmark is not None \
-            and isinstance(benchmark, _pd.DataFrame) and len(benchmark.columns) > 1:
-        raise ValueError("`benchmark` must be a pandas Series, "
-                         "but a multi-column DataFrame was passed")
+    benchmark_col = 'Benchmark'
+    if benchmark is not None:
+        if isinstance(benchmark, str):
+            benchmark_col = f'Benchmark ({benchmark.upper()})'
+        elif isinstance(benchmark, _pd.DataFrame) and len(benchmark.columns) > 1:
+            raise ValueError("`benchmark` must be a pandas Series, "
+                             "but a multi-column DataFrame was passed")
 
     blank = ['']
 
@@ -415,14 +420,22 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     metrics['~~~~~~~~~~~~~~'] = blank
 
     metrics['Sharpe'] = _stats.sharpe(df, rf, win_year, True)
+    metrics['Prob. Sharpe Ratio %'] = _stats.probabilistic_sharpe_ratio(df, rf, win_year, False) * pct
     if mode.lower() == 'full':
         metrics['Smart Sharpe'] = _stats.smart_sharpe(df, rf, win_year, True)
+        # metrics['Prob. Smart Sharpe Ratio %'] = _stats.probabilistic_sharpe_ratio(df, rf, win_year, False, True) * pct
+
     metrics['Sortino'] = _stats.sortino(df, rf, win_year, True)
     if mode.lower() == 'full':
+        # metrics['Prob. Sortino Ratio %'] = _stats.probabilistic_sortino_ratio(df, rf, win_year, False) * pct
         metrics['Smart Sortino'] = _stats.smart_sortino(df, rf, win_year, True)
+        # metrics['Prob. Smart Sortino Ratio %'] = _stats.probabilistic_sortino_ratio(df, rf, win_year, False, True) * pct
+
     metrics['Sortino/√2'] = metrics['Sortino'] / _sqrt(2)
     if mode.lower() == 'full':
+        # metrics['Prob. Sortino/√2 Ratio %'] = _stats.probabilistic_adjusted_sortino_ratio(df, rf, win_year, False) * pct
         metrics['Smart Sortino/√2'] = metrics['Smart Sortino'] / _sqrt(2)
+        # metrics['Prob. Smart Sortino/√2 Ratio %'] = _stats.probabilistic_adjusted_sortino_ratio(df, rf, win_year, False, True) * pct
     metrics['Omega'] = _stats.omega(df, rf, 0., win_year)
 
     metrics['~~~~~~~~'] = blank
@@ -438,6 +451,8 @@ def metrics(returns, benchmark=None, rf=0., display=True,
             metrics['Volatility (ann.) %'] = [ret_vol, bench_vol]
             metrics['R^2'] = _stats.r_squared(
                 df['returns'], df['benchmark'], prepare_returns=False)
+            metrics['Information Ratio'] = _stats.information_ratio(
+                df['returns'], df['benchmark'], prepare_returns=False)
         else:
             metrics['Volatility (ann.) %'] = [ret_vol]
 
@@ -465,6 +480,10 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
     metrics['~~~~~~'] = blank
 
+    if mode.lower() == 'full':
+        metrics['Max Consecutive Wins *int'] = _stats.consecutive_wins(df)
+        metrics['Max Consecutive Losses *int'] = _stats.consecutive_losses(df)
+
     metrics['Gain/Pain Ratio'] = _stats.gain_to_pain_ratio(df, rf)
     metrics['Gain/Pain (1M)'] = _stats.gain_to_pain_ratio(df, rf, "M")
     # if mode.lower() == 'full':
@@ -486,34 +505,28 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     comp_func = _stats.comp if compounded else _np.sum
 
     today = df.index[-1]  # _dt.today()
-    metrics['MTD %'] = comp_func(
-        df[df.index >= _dt(today.year, today.month, 1)]) * pct
+    metrics['MTD %'] = comp_func(df[df.index >= _dt(today.year, today.month, 1)]) * pct
 
-    d = today - _td(3*365/12)
-    metrics['3M %'] = comp_func(
-        df[df.index >= _dt(d.year, d.month, d.day)]) * pct
+    d = today - relativedelta(months=3)
+    metrics['3M %'] = comp_func(df[df.index >= d]) * pct
 
-    d = today - _td(6*365/12)
-    metrics['6M %'] = comp_func(
-        df[df.index >= _dt(d.year, d.month, d.day)]) * pct
+    d = today - relativedelta(months=6)
+    metrics['6M %'] = comp_func(df[df.index >= d]) * pct
 
     metrics['YTD %'] = comp_func(df[df.index >= _dt(today.year, 1, 1)]) * pct
 
-    d = today - _td(12*365/12)
-    metrics['1Y %'] = comp_func(
-        df[df.index >= _dt(d.year, d.month, d.day)]) * pct
-    d = today - _td(3*365)
-    metrics['3Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(d.year, d.month, d.day)
-           ], 0., compounded) * pct
-    d = today - _td(5*365)
-    metrics['5Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(d.year, d.month, d.day)
-           ], 0., compounded) * pct
-    d = today - _td(10*365)
-    metrics['10Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(d.year, d.month, d.day)
-           ], 0., compounded) * pct
+    d = today - relativedelta(years=1)
+    metrics['1Y %'] = comp_func(df[df.index >= d]) * pct
+
+    d = today - relativedelta(months=35)
+    metrics['3Y (ann.) %'] = _stats.cagr(df[df.index >= d], 0., compounded) * pct
+
+    d = today - relativedelta(months=59)
+    metrics['5Y (ann.) %'] = _stats.cagr(df[df.index >= d], 0., compounded) * pct
+
+    d = today - relativedelta(years=10)
+    metrics['10Y (ann.) %'] = _stats.cagr(df[df.index >= d], 0., compounded) * pct
+
     metrics['All-time (ann.) %'] = _stats.cagr(df, 0., compounded) * pct
 
     # best/worst
@@ -545,10 +558,12 @@ def metrics(returns, benchmark=None, rf=0., display=True,
         metrics['Win Year %%'] = _stats.win_rate(df, aggregate='A', prepare_returns=False) * pct
 
         if "benchmark" in df:
-            metrics['~~~~~~~'] = blank
+            metrics['~~~~~~~~~~~~'] = blank
             greeks = _stats.greeks(df['returns'], df['benchmark'], win_year, prepare_returns=False)
             metrics['Beta'] = [str(round(greeks['beta'], 2)), '-']
             metrics['Alpha'] = [str(round(greeks['alpha'], 2)), '-']
+            metrics['Correlation'] = [str(round(df['benchmark'].corr(df['returns']) * pct, 2))+'%', '-']
+            metrics['Treynor Ratio'] = [str(round(_stats.treynor_ratio(df['returns'], df['benchmark'], win_year, rf)*pct, 2))+'%', '-']
 
     # prepare for display
     for col in metrics.columns:
@@ -558,6 +573,9 @@ def metrics(returns, benchmark=None, rf=0., display=True,
                 metrics[col] = metrics[col].astype(str)
         except Exception:
             pass
+        if (display or "internal" in kwargs) and "*int" in col:
+            metrics[col] = metrics[col].str.replace('.0', '', regex=False)
+            metrics.rename({col: col.replace("*int", "")}, axis=1, inplace=True)
         if (display or "internal" in kwargs) and "%" in col:
             metrics[col] = metrics[col] + '%'
     try:
@@ -584,16 +602,28 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     metrics = metrics.T
 
     if "benchmark" in df:
-        metrics.columns = ['Strategy', 'Benchmark']
+        metrics.columns = ['Strategy', benchmark_col]
     else:
         metrics.columns = ['Strategy']
 
+    # cleanups
+    metrics.replace([-0, '-0'], 0, inplace=True)
+    metrics.replace([_np.nan, -_np.nan, _np.inf, -_np.inf,
+                     '-nan%', 'nan%', '-nan', 'nan',
+                    '-inf%', 'inf%', '-inf', 'inf'], '-', inplace=True)
+
     if display:
         print(_tabulate(metrics, headers="keys", tablefmt='simple'))
         return None
 
     if not sep:
         metrics = metrics[metrics.index != '']
+
+    # remove spaces from column names
+    metrics = metrics.T
+    metrics.columns = [c.replace(' %', '').replace(' *int', '').strip() for c in metrics.columns]
+    metrics = metrics.T
+
     return metrics
 
 
